const fs = require('fs');

const TEMP_FILE_PATH = './.codemod-update-imports';
const COMMUNITY_ORG = '@react-native-community/';
const DEPRECATED_MODULES = {
  AsyncStorage: 'async-storage',
  MaskedViewIOS: 'masked-view',
  ViewPagerAndroid: 'viewpager',
  Slider: 'slider',
  NetInfo: 'netinfo',
};

let addedPackages = [];

module.exports = function(file, api, options) {
  const j = api.jscodeshift;
  const root = j(file.source);

  const importDeclaration = root.find(j.ImportDeclaration, {
    source: {
      type: 'Literal',
      value: 'react-native',
    },
  });

  const importSpecifiers = importDeclaration.find(j.ImportSpecifier);

  importSpecifiers.forEach(node => {
    const { name: moduleName } = node.value.imported;
    const { name: localName } = node.value.local;

    const modulePackage = DEPRECATED_MODULES[moduleName];

    if (!modulePackage) {
      return node;
    }

    const importPackage = `${COMMUNITY_ORG}${modulePackage}`;

    importDeclaration.insertAfter(j.importDeclaration([j.importDefaultSpecifier(j.identifier(localName))], j.literal(importPackage)));

    j(node).remove();

    addedPackages.push(importPackage);

    return node;
  });

  if (importDeclaration.find(j.ImportSpecifier).length === 0) {
    importDeclaration.remove();
  }

  if (addedPackages.length > 0) {
    fs.writeFileSync(TEMP_FILE_PATH, addedPackages.join('\n'), 'utf-8');
  }

  return root.toSource();
};
